summary refs log tree commit diff
path: root/src/test
diff options
context:
space:
mode:
authorBrian Anderson <banderson@mozilla.com>2011-09-01 18:49:10 -0700
committerBrian Anderson <banderson@mozilla.com>2011-09-01 18:54:03 -0700
commit418d09e547a021ad4853680f7efc3efc8774054c (patch)
treeb6cd0c22529d90105a7cc1d87fde5504f31031f5 /src/test
parentb4b81117ce3713599b48d2168bf10e0225f94819 (diff)
downloadrust-418d09e547a021ad4853680f7efc3efc8774054c.tar.gz
rust-418d09e547a021ad4853680f7efc3efc8774054c.zip
Convert all uses of #ifmt to #fmt. Issue #855
Diffstat (limited to 'src/test')
-rw-r--r--src/test/bench/shootout-binarytrees.rs6
-rw-r--r--src/test/bench/shootout-fannkuchredux.rs2
-rw-r--r--src/test/bench/shootout-pfib.rs4
-rw-r--r--src/test/bench/task-perf-word-count-generic.rs4
-rw-r--r--src/test/bench/task-perf-word-count.rs4
-rw-r--r--src/test/compile-fail/ext-after-attrib.rs4
-rw-r--r--src/test/compile-fail/extfmt-missing-type.rs2
-rw-r--r--src/test/compile-fail/extfmt-no-args.rs2
-rw-r--r--src/test/compile-fail/extfmt-non-literal.rs4
-rw-r--r--src/test/compile-fail/extfmt-non-literal2.rs4
-rw-r--r--src/test/compile-fail/extfmt-not-enough-args.rs2
-rw-r--r--src/test/compile-fail/extfmt-too-many-args.rs2
-rw-r--r--src/test/compile-fail/extfmt-unknown-type.rs2
-rw-r--r--src/test/compile-fail/extfmt-unsigned-plus.rs2
-rw-r--r--src/test/compile-fail/extfmt-unsigned-space.rs2
-rw-r--r--src/test/compile-fail/extfmt-unterminated-conv.rs2
-rw-r--r--src/test/compiletest/compiletest.rs34
-rw-r--r--src/test/compiletest/header.rs2
-rw-r--r--src/test/compiletest/runtest.rs30
-rw-r--r--src/test/compiletest/util.rs2
-rw-r--r--src/test/run-fail/fmt-fail.rs2
-rw-r--r--src/test/run-pass/item-attributes.rs2
-rw-r--r--src/test/stdtest/qsort.rs2
23 files changed, 61 insertions, 61 deletions
diff --git a/src/test/bench/shootout-binarytrees.rs b/src/test/bench/shootout-binarytrees.rs
index d0896241c9e..d6a44e6eb82 100644
--- a/src/test/bench/shootout-binarytrees.rs
+++ b/src/test/bench/shootout-binarytrees.rs
@@ -28,7 +28,7 @@ fn main() {
     } else { max_depth = n; }
     let stretch_depth = max_depth + 1;
     let stretch_tree = bottom_up_tree(0, stretch_depth);
-    log #ifmt["stretch tree of depth %d\t check: %d", stretch_depth,
+    log #fmt["stretch tree of depth %d\t check: %d", stretch_depth,
              item_check(stretch_tree)];
     let long_lived_tree = bottom_up_tree(0, max_depth);
     let depth = min_depth;
@@ -43,10 +43,10 @@ fn main() {
             chk += item_check(temp_tree);
             i += 1;
         }
-        log #ifmt["%d\t trees of depth %d\t check: %d", iterations * 2, depth,
+        log #fmt["%d\t trees of depth %d\t check: %d", iterations * 2, depth,
                  chk];
         depth += 2;
     }
-    log #ifmt["long lived trees of depth %d\t check: %d", max_depth,
+    log #fmt["long lived trees of depth %d\t check: %d", max_depth,
              item_check(long_lived_tree)];
 }
diff --git a/src/test/bench/shootout-fannkuchredux.rs b/src/test/bench/shootout-fannkuchredux.rs
index c36fe8d832a..fa4a17180ae 100644
--- a/src/test/bench/shootout-fannkuchredux.rs
+++ b/src/test/bench/shootout-fannkuchredux.rs
@@ -58,5 +58,5 @@ fn fannkuch(n: int) -> int {
 
 fn main(args: [istr]) {
     let n = 7;
-    log #ifmt["Pfannkuchen(%d) = %d", n, fannkuch(n)];
+    log #fmt["Pfannkuchen(%d) = %d", n, fannkuch(n)];
 }
diff --git a/src/test/bench/shootout-pfib.rs b/src/test/bench/shootout-pfib.rs
index b9fba948561..6a9a5348c2e 100644
--- a/src/test/bench/shootout-pfib.rs
+++ b/src/test/bench/shootout-pfib.rs
@@ -67,7 +67,7 @@ fn stress_task(id: int) {
         let n = 15;
         assert (fib(n) == fib(n));
         i += 1;
-        log_err #ifmt["%d: Completed %d iterations", id, i];
+        log_err #fmt["%d: Completed %d iterations", id, i];
     }
 }
 
@@ -106,7 +106,7 @@ fn main(argv: [istr]) {
                     let elapsed = stop - start;
 
                     out.write_line(
-                            #ifmt["%d\t%d\t%s", n, fibn,
+                            #fmt["%d\t%d\t%s", n, fibn,
                                  u64::str(elapsed)]);
                 }
             }
diff --git a/src/test/bench/task-perf-word-count-generic.rs b/src/test/bench/task-perf-word-count-generic.rs
index 5d01e725ed3..3a8f643bc37 100644
--- a/src/test/bench/task-perf-word-count-generic.rs
+++ b/src/test/bench/task-perf-word-count-generic.rs
@@ -127,7 +127,7 @@ mod map_reduce {
             while !is_done || ref_count > 0 {
                 alt recv(p) {
                   emit_val(v) {
-                    // log_err #ifmt("received %d", v);
+                    // log_err #fmt("received %d", v);
                     ret some(v);
                   }
                   done. {
@@ -202,7 +202,7 @@ fn main(argv: [istr]) {
         let out = io::stdout();
 
         out.write_line(
-            #ifmt["Usage: %s <filename> ...", argv[0]]);
+            #fmt["Usage: %s <filename> ...", argv[0]]);
 
         // TODO: run something just to make sure the code hasn't
         // broken yet. This is the unit test mode of this program.
diff --git a/src/test/bench/task-perf-word-count.rs b/src/test/bench/task-perf-word-count.rs
index e947d6bd1d9..c62ebc73b5d 100644
--- a/src/test/bench/task-perf-word-count.rs
+++ b/src/test/bench/task-perf-word-count.rs
@@ -122,7 +122,7 @@ mod map_reduce {
             while !is_done || ref_count > 0 {
                 alt recv(p) {
                   emit_val(v) {
-                    // log_err #ifmt("received %d", v);
+                    // log_err #fmt("received %d", v);
                     ret some(v);
                   }
                   done. {
@@ -196,7 +196,7 @@ fn main(argv: [istr]) {
         let out = io::stdout();
 
         out.write_line(
-            #ifmt["Usage: %s <filename> ...", argv[0]]);
+            #fmt["Usage: %s <filename> ...", argv[0]]);
 
         // TODO: run something just to make sure the code hasn't
         // broken yet. This is the unit test mode of this program.
diff --git a/src/test/compile-fail/ext-after-attrib.rs b/src/test/compile-fail/ext-after-attrib.rs
index 7d9d7770b89..ef15958c3fc 100644
--- a/src/test/compile-fail/ext-after-attrib.rs
+++ b/src/test/compile-fail/ext-after-attrib.rs
@@ -1,7 +1,7 @@
-// error-pattern:expecting [, found ifmt
+// error-pattern:expecting [, found fmt
 
 // Don't know how to deal with a syntax extension appearing after an
 // item attribute. Probably could use a better error message.
 #[foo = "bar"]
-#ifmt("baz")
+#fmt("baz")
 fn main() { }
\ No newline at end of file
diff --git a/src/test/compile-fail/extfmt-missing-type.rs b/src/test/compile-fail/extfmt-missing-type.rs
index 55adc1caec5..9e1cbc557d4 100644
--- a/src/test/compile-fail/extfmt-missing-type.rs
+++ b/src/test/compile-fail/extfmt-missing-type.rs
@@ -1,3 +1,3 @@
 // error-pattern:missing type
 
-fn main() { #ifmt["%+"]; }
+fn main() { #fmt["%+"]; }
diff --git a/src/test/compile-fail/extfmt-no-args.rs b/src/test/compile-fail/extfmt-no-args.rs
index c69a4410fe0..7c13ef99dc5 100644
--- a/src/test/compile-fail/extfmt-no-args.rs
+++ b/src/test/compile-fail/extfmt-no-args.rs
@@ -1,3 +1,3 @@
 // error-pattern:format string
 
-fn main() { #ifmt[]; }
+fn main() { #fmt[]; }
diff --git a/src/test/compile-fail/extfmt-not-enough-args.rs b/src/test/compile-fail/extfmt-not-enough-args.rs
index beb9d3d8e96..849a836060d 100644
--- a/src/test/compile-fail/extfmt-not-enough-args.rs
+++ b/src/test/compile-fail/extfmt-not-enough-args.rs
@@ -2,4 +2,4 @@
 
 use std;
 
-fn main() { let s = #ifmt["%s%s%s", "test", "test"]; }
+fn main() { let s = #fmt["%s%s%s", "test", "test"]; }
diff --git a/src/test/compile-fail/extfmt-too-many-args.rs b/src/test/compile-fail/extfmt-too-many-args.rs
index 393fd4ca618..4c91da227e1 100644
--- a/src/test/compile-fail/extfmt-too-many-args.rs
+++ b/src/test/compile-fail/extfmt-too-many-args.rs
@@ -2,4 +2,4 @@
 
 use std;
 
-fn main() { let s = #ifmt["%s", "test", "test"]; }
+fn main() { let s = #fmt["%s", "test", "test"]; }
diff --git a/src/test/compile-fail/extfmt-unknown-type.rs b/src/test/compile-fail/extfmt-unknown-type.rs
index 7d2ce0902de..3a35a1d727b 100644
--- a/src/test/compile-fail/extfmt-unknown-type.rs
+++ b/src/test/compile-fail/extfmt-unknown-type.rs
@@ -1,3 +1,3 @@
 // error-pattern:unknown type
 
-fn main() { #ifmt["%w"]; }
+fn main() { #fmt["%w"]; }
diff --git a/src/test/compile-fail/extfmt-unsigned-plus.rs b/src/test/compile-fail/extfmt-unsigned-plus.rs
index 1dfce7e89c4..4ac41efb312 100644
--- a/src/test/compile-fail/extfmt-unsigned-plus.rs
+++ b/src/test/compile-fail/extfmt-unsigned-plus.rs
@@ -2,5 +2,5 @@
 
 fn main() {
     // Can't use a sign on unsigned conversions
-    #ifmt["%+u", 10u];
+    #fmt["%+u", 10u];
 }
diff --git a/src/test/compile-fail/extfmt-unsigned-space.rs b/src/test/compile-fail/extfmt-unsigned-space.rs
index 2866c569ff1..6393548eb3d 100644
--- a/src/test/compile-fail/extfmt-unsigned-space.rs
+++ b/src/test/compile-fail/extfmt-unsigned-space.rs
@@ -2,5 +2,5 @@
 
 fn main() {
     // Can't use a space on unsigned conversions
-    #ifmt["% u", 10u];
+    #fmt["% u", 10u];
 }
diff --git a/src/test/compile-fail/extfmt-unterminated-conv.rs b/src/test/compile-fail/extfmt-unterminated-conv.rs
index 19cd69c7f69..3b7d0ce1767 100644
--- a/src/test/compile-fail/extfmt-unterminated-conv.rs
+++ b/src/test/compile-fail/extfmt-unterminated-conv.rs
@@ -1,3 +1,3 @@
 // error-pattern:unterminated conversion
 
-fn main() { #ifmt["%"]; }
+fn main() { #fmt["%"]; }
diff --git a/src/test/compiletest/compiletest.rs b/src/test/compiletest/compiletest.rs
index 70448274984..5f3fd1944dd 100644
--- a/src/test/compiletest/compiletest.rs
+++ b/src/test/compiletest/compiletest.rs
@@ -70,21 +70,21 @@ fn parse_config(args: &[istr]) -> config {
 
 fn log_config(config: &config) {
     let c = config;
-    logv(c, #ifmt["configuration:"]);
-    logv(c, #ifmt["compile_lib_path: %s",
+    logv(c, #fmt["configuration:"]);
+    logv(c, #fmt["compile_lib_path: %s",
                  config.compile_lib_path]);
-    logv(c, #ifmt["run_lib_path: %s", config.run_lib_path]);
-    logv(c, #ifmt["rustc_path: %s", config.rustc_path]);
-    logv(c, #ifmt["src_base: %s", config.src_base]);
-    logv(c, #ifmt["build_base: %s", config.build_base]);
-    logv(c, #ifmt["stage_id: %s", config.stage_id]);
-    logv(c, #ifmt["mode: %s", mode_str(config.mode)]);
-    logv(c, #ifmt["run_ignored: %b", config.run_ignored]);
-    logv(c, #ifmt["filter: %s", opt_str(config.filter)]);
-    logv(c, #ifmt["runtool: %s", opt_str(config.runtool)]);
-    logv(c, #ifmt["rustcflags: %s", opt_str(config.rustcflags)]);
-    logv(c, #ifmt["verbose: %b", config.verbose]);
-    logv(c, #ifmt["\n"]);
+    logv(c, #fmt["run_lib_path: %s", config.run_lib_path]);
+    logv(c, #fmt["rustc_path: %s", config.rustc_path]);
+    logv(c, #fmt["src_base: %s", config.src_base]);
+    logv(c, #fmt["build_base: %s", config.build_base]);
+    logv(c, #fmt["stage_id: %s", config.stage_id]);
+    logv(c, #fmt["mode: %s", mode_str(config.mode)]);
+    logv(c, #fmt["run_ignored: %b", config.run_ignored]);
+    logv(c, #fmt["filter: %s", opt_str(config.filter)]);
+    logv(c, #fmt["runtool: %s", opt_str(config.runtool)]);
+    logv(c, #fmt["rustcflags: %s", opt_str(config.rustcflags)]);
+    logv(c, #fmt["verbose: %b", config.verbose]);
+    logv(c, #fmt["\n"]);
 }
 
 fn opt_str(maybestr: option::t<istr>) -> istr {
@@ -139,12 +139,12 @@ type tests_and_conv_fn =
     {tests: [test::test_desc], to_task: fn(&fn()) -> test::joinable};
 
 fn make_tests(cx: &cx) -> tests_and_conv_fn {
-    log #ifmt["making tests from %s", cx.config.src_base];
+    log #fmt["making tests from %s", cx.config.src_base];
     let configport = port::<[u8]>();
     let tests = [];
     for file: istr in fs::list_dir(cx.config.src_base) {
         let file = file;
-        log #ifmt["inspecting file %s", file];
+        log #fmt["inspecting file %s", file];
         if is_test(cx.config, file) {
             tests += [make_test(cx, file, configport)];
         }
@@ -182,7 +182,7 @@ fn make_test(cx: &cx, testfile: &istr, configport: &port<[u8]>) ->
 }
 
 fn make_test_name(config: &config, testfile: &istr) -> istr {
-    #ifmt["[%s] %s", mode_str(config.mode), testfile]
+    #fmt["[%s] %s", mode_str(config.mode), testfile]
 }
 
 /*
diff --git a/src/test/compiletest/header.rs b/src/test/compiletest/header.rs
index 5a4a0ea095b..d891e87f5dd 100644
--- a/src/test/compiletest/header.rs
+++ b/src/test/compiletest/header.rs
@@ -114,7 +114,7 @@ fn parse_name_value_directive(line: &istr,
         let value =
             str::slice(line, colon + str::byte_len(keycolon),
                        str::byte_len(line));
-        log #ifmt("%s: %s", directive,
+        log #fmt("%s: %s", directive,
                   value);
         option::some(value)
     } else { option::none }
diff --git a/src/test/compiletest/util.rs b/src/test/compiletest/util.rs
index 88320d29dc1..b15e16b5d4d 100644
--- a/src/test/compiletest/util.rs
+++ b/src/test/compiletest/util.rs
@@ -11,7 +11,7 @@ fn make_new_path(path: &istr) -> istr {
     // maintain the current value while adding our own
     alt getenv(lib_path_env_var()) {
       option::some(curr) {
-        #ifmt["%s:%s", path, curr] }
+        #fmt["%s:%s", path, curr] }
       option::none. { path }
     }
 }
diff --git a/src/test/run-fail/fmt-fail.rs b/src/test/run-fail/fmt-fail.rs
index 67814d12c45..2791db07446 100644
--- a/src/test/run-fail/fmt-fail.rs
+++ b/src/test/run-fail/fmt-fail.rs
@@ -2,4 +2,4 @@
 // no-valgrind
 use std;
 
-fn main() { let str_var: istr = ~"meh"; fail #ifmt["%s", str_var]; }
+fn main() { let str_var: istr = ~"meh"; fail #fmt["%s", str_var]; }
diff --git a/src/test/run-pass/item-attributes.rs b/src/test/run-pass/item-attributes.rs
index 58d38ba94f4..dd5fb0b18b3 100644
--- a/src/test/run-pass/item-attributes.rs
+++ b/src/test/run-pass/item-attributes.rs
@@ -167,7 +167,7 @@ mod test_distinguish_syntax_ext {
     use std;
 
     fn f() {
-        #ifmt["test%s", ~"s"];
+        #fmt["test%s", ~"s"];
         #[attr = "val"]
         fn g() { }
     }
diff --git a/src/test/stdtest/qsort.rs b/src/test/stdtest/qsort.rs
index 8aaf9c61428..32109dc1caa 100644
--- a/src/test/stdtest/qsort.rs
+++ b/src/test/stdtest/qsort.rs
@@ -54,7 +54,7 @@ fn test_simple() {
  // Silly, but what else can we do?
     check vec::same_length(expected, immut_names);
     let pairs = vec::zip(expected, immut_names);
-    for (a, b) in pairs { log #ifmt["%d %d", a, b]; assert (a == b); }
+    for (a, b) in pairs { log #fmt["%d %d", a, b]; assert (a == b); }
 }
 
 // Local Variables:
diff --git a/src/test/compile-fail/extfmt-non-literal.rs b/src/test/compile-fail/extfmt-non-literal.rs
index 451e020fcaf..445455f33d8 100644
--- a/src/test/compile-fail/extfmt-non-literal.rs
+++ b/src/test/compile-fail/extfmt-non-literal.rs
@@ -1,8 +1,8 @@
 // error-pattern: literal
 
 fn main() {
     // #ifmt's first argument must be a literal.  Hopefully this
     // restriction can be eased eventually to just require a
     // compile-time constant.
-    let x = #ifmt["a" + "b"];
+    let x = #fmt["a" + "b"];
 }
@@ -1,8 +1,8 @@
 
 fn main() {
-    // #ifmt's first argument must be a literal.  Hopefully this
+    // #fmt's first argument must be a literal.  Hopefully this
     // restriction can be eased eventually to just require a
     // compile-time constant.
diff --git a/src/test/compile-fail/extfmt-non-literal2.rs b/src/test/compile-fail/extfmt-non-literal2.rs
index 19af91bfcc7..8a2d7c4bbed 100644
--- a/src/test/compile-fail/extfmt-non-literal2.rs
+++ b/src/test/compile-fail/extfmt-non-literal2.rs
@@ -1,8 +1,8 @@
 // error-pattern: literal
 
 fn main() {
     // #ifmt's first argument must be a literal.  Hopefully this
     // restriction can be eased eventually to just require a
     // compile-time constant.
-    let x = #ifmt[20];
+    let x = #fmt[20];
 }
@@ -1,8 +1,8 @@
 
 fn main() {
-    // #ifmt's first argument must be a literal.  Hopefully this
+    // #fmt's first argument must be a literal.  Hopefully this
     // restriction can be eased eventually to just require a
     // compile-time constant.
diff --git a/src/test/compiletest/runtest.rs b/src/test/compiletest/runtest.rs
index e8e51919680..9128160855b 100644
--- a/src/test/compiletest/runtest.rs
+++ b/src/test/compiletest/runtest.rs
@@ -24,7 +24,7 @@ fn run(cx: &cx, _testfile: -[u8]) {
         // We're going to be dumping a lot of info. Start on a new line.
         io::stdout().write_str(~"\n\n");
     }
-    log #ifmt["running %s", testfile];
+    log #fmt["running %s", testfile];
     let props = load_props(testfile);
     alt cx.config.mode {
       mode_compile_fail. { run_cfail_test(cx, props, testfile); }
@@ -90,12 +90,12 @@ fn run_pretty_test(cx: &cx, props: &test_props, testfile: &istr) {
 
     let round = 0;
     while round < rounds {
-        logv(cx.config, #ifmt["pretty-printing round %d", round]);
+        logv(cx.config, #fmt["pretty-printing round %d", round]);
         let procres = print_source(cx, testfile, srcs[round]);
 
         if procres.status != 0 {
             fatal_procres(
                     #ifmt["pretty-printing failed in round %d", round],
                     procres);
         }
 
@@ -147,7 +147,7 @@ fn run_pretty_test(cx: &cx, props: &test_props, testfile: &istr) {
         if expected != actual {
             error(~"pretty-printed source does match expected source");
             let msg =
-                #ifmt["\n\
+                #fmt["\n\
 expected:\n\
 ------------------------------------------\n\
 %s\n\
@@ -190,7 +190,7 @@ fn check_error_patterns(props: &test_props, testfile: &istr,
     let next_err_pat = props.error_patterns[next_err_idx];
     for line: istr in str::split(procres.stdout, '\n' as u8) {
         if str::find(line, next_err_pat) > 0 {
-            log #ifmt["found error pattern %s",
+            log #fmt["found error pattern %s",
                       next_err_pat];
             next_err_idx += 1u;
             if next_err_idx == vec::len(props.error_patterns) {
@@ -206,11 +206,11 @@ fn check_error_patterns(props: &test_props, testfile: &istr,
                    vec::len(props.error_patterns));
     if vec::len(missing_patterns) == 1u {
         fatal_procres(
-            #ifmt["error pattern '%s' not found!",
+            #fmt["error pattern '%s' not found!",
                   missing_patterns[0]], procres);
     } else {
         for pattern: istr in missing_patterns {
-            error(#ifmt["error pattern '%s' not found!",
+            error(#fmt["error pattern '%s' not found!",
                         pattern]);
         }
         fatal_procres(~"multiple error patterns not found", procres);
@@ -299,7 +299,7 @@ fn program_output(cx: &cx, testfile: &istr, lib_path: &istr, prog: &istr,
     let cmdline =
         {
             let cmdline = make_cmdline(lib_path, prog, args);
-            logv(cx.config, #ifmt["executing %s",
+            logv(cx.config, #fmt["executing %s",
                                   cmdline]);
             cmdline
         };
@@ -312,7 +312,7 @@ fn program_output(cx: &cx, testfile: &istr, lib_path: &istr, prog: &istr,
 }
 
 fn make_cmdline(libpath: &istr, prog: &istr, args: &[istr]) -> istr {
-    #ifmt["%s %s %s",
+    #fmt["%s %s %s",
           lib_path_cmd_prefix(libpath),
           prog,
           str::connect(args, ~" ")]
@@ -321,7 +321,7 @@ fn make_cmdline(libpath: &istr, prog: &istr, args: &[istr]) -> istr {
 // Build the LD_LIBRARY_PATH variable as it would be seen on the command line
 // for diagnostic purposes
 fn lib_path_cmd_prefix(path: &istr) -> istr {
-        #ifmt["%s=\"%s\"",
+        #fmt["%s=\"%s\"",
               util::lib_path_env_var(),
               util::make_new_path(path)]
 }
@@ -362,14 +362,14 @@ fn output_base_name(config: &config, testfile: &istr) -> istr {
             parts = vec::slice(parts, 0u, vec::len(parts) - 1u);
             str::connect(parts, ~".")
         };
-    #ifmt["%s%s.%s", base, filename,
+    #fmt["%s%s.%s", base, filename,
                         config.stage_id]
 }
 
 fn maybe_dump_to_stdout(config: &config, out: &istr, err: &istr) {
     if config.verbose {
-        let sep1 = #ifmt["------%s------------------------------", ~"stdout"];
-        let sep2 = #ifmt["------%s------------------------------", ~"stderr"];
+        let sep1 = #fmt["------%s------------------------------", ~"stdout"];
+        let sep2 = #fmt["------%s------------------------------", ~"stderr"];
         let sep3 = ~"------------------------------------------";
         io::stdout().write_line(sep1);
         io::stdout().write_line(out);
@@ -380,14 +380,14 @@ fn maybe_dump_to_stdout(config: &config, out: &istr, err: &istr) {
 }
 
 fn error(err: &istr) {
-    io::stdout().write_line(#ifmt["\nerror: %s", err]);
+    io::stdout().write_line(#fmt["\nerror: %s", err]);
 }
 
 fn fatal(err: &istr) -> ! { error(err); fail; }
 
 fn fatal_procres(err: &istr, procres: procres) -> ! {
     let msg =
-        #ifmt["\n\
+        #fmt["\n\
 error: %s\n\
 command: %s\n\
 stdout:\n\
@@ -90,12 +90,12 @@ fn run_pretty_test(cx: &cx, props: &test_props, testfile: &istr) {
         if procres.status != 0 {
             fatal_procres(
-                    #ifmt["pretty-printing failed in round %d", round],
+                    #fmt["pretty-printing failed in round %d", round],
                     procres);
         }